@@ -1,8 +1,8 @@
 # -*- coding:utf-8 -*-
-from .Cpath import *
+from .cpath import *
 
 __title__ = 'cgai_path'
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 __author__ = 'Master Zhang'
 __author_email__ = '360014296@qq.com'
 __license__ = 'GPLv3'
